==> emodpy_measles-0.0.28-py3-none-any.whl: tests/test_camp_interventions.py <==
#!/usr/bin/env python


from emodpy_measles.interventions import *
import unittest
import emod_api.campaign as camp
import json
import os

#event = ConstructHistoricalCampaigns()

class TestCampInterventions(unittest.TestCase):

    is_debugging = True

    def validate_measles_vaccine(self):
        target_event = self.campaign['Events'][0]
        coverage = target_event['Event_Coordinator_Config']['Demographic_Coverage']
        start_day = target_event['Start_Day']
        intervention_name = target_event['Event_Coordinator_Config']['Intervention_Config']['Intervention_Name']

        self.assertEqual(coverage, self.coverage)
        self.assertEqual(start_day, self.timestep + 1)
        self.assertEqual(intervention_name, "DelayedIntervention")

    def test_simplemcv1_default(self):
        import emodpy_measles.interventions.measles_vaccine as mv
        camp.schema_path = "schema.json"

        # testing that intervention as file creates file
        try:
            camp_filename = mv.new_intervention_as_file( 10 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(10) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(10) -- " + str( ex ) )

        self.coverage = 1
        self.timestep = 1

        event = mv.SimpleMCV1(timestep=1)
        camp.add(event, first=True)
        camp.add(mv.SimpleMCV1(timestep=10))

        camp_file = "campaign_simple_mcv1.json"
        camp.save( camp_file )

        self.assertTrue(os.path.exists(camp_file))
        
        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)
        
        # Check that events are being added properly
        self.assertEqual(len(self.campaign['Events']), 2)
        self.validate_measles_vaccine()

        if not self.is_debugging:
            os.remove(camp_file)

    def test_simplemcv1_custom(self):
        import emodpy_measles.interventions.measles_vaccine as mv
        camp.schema_path = "schema.json"

        # testing that intervention as file creates file
        try:
            camp_filename = mv.new_intervention_as_file( 10 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(10) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(10) -- " + str( ex ) )

        self.coverage = 1.0
        self.timestep = 5


        event = mv.SimpleMCV1(coverage=self.coverage, timestep=self.timestep)
        camp.add(event, first=True)

        camp_file = "campaign_simple_mcv1.json"
        camp.save( camp_file )

        self.assertTrue(os.path.exists(camp_file))
        
        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)

        self.validate_measles_vaccine()

        if not self.is_debugging:
            os.remove(camp_file)

    def validate_complex_import(self):
        intervention_config = self.campaign['Events'][0]['Event_Coordinator_Config']['Intervention_Config']
        dips = intervention_config['Daily_Import_Pressures']
        durations = intervention_config['Durations']
        start_day = self.campaign['Events'][0]['Start_Day']

        self.assertEqual(dips, self.dips)
        self.assertEqual(start_day, self.timestep + 1)
        self.assertEqual(durations, self.durations)

    def test_complex_import_default(self):
        import emodpy_measles.interventions.complex_import as ci
        ci.schema_path = "schema.json"

        try:
            camp_filename = ci.new_intervention_as_file( 10 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(10) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(10) -- " + str( ex ) )

        self.durations  = [100000]
        self.dips =[1/(774*10)]
        self.timestep=1
        event = ci.ComplexImportationEvent()
        camp.add(event, first=True)


        camp_file = "campaign_complex_import.json"
        camp.save( camp_file )
        self.assertTrue(os.path.exists(camp_file))
        
        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)

        self.validate_complex_import()

        if not self.is_debugging:
            os.remove(camp_file)

    def test_complex_import_custom(self):
        import emodpy_measles.interventions.complex_import as ci
        ci.schema_path = "schema.json"

        try:
            camp_filename = ci.new_intervention_as_file( 10 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(10) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(10) -- " + str( ex ) )

        self.durations  = [10, 10, 11, 15]
        self.dips =[10, 10, 11, 7]
        self.timestep=10
        event = ci.ComplexImportationEvent(durs=self.durations, dips=self.dips, timestep=10)
        camp.add(event, first=True)


        camp_file = "campaign_complex_import.json"
        camp.save( camp_file )
        self.assertTrue(os.path.exists(camp_file))
        
        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)

        self.validate_complex_import()

        if not self.is_debugging:
            os.remove(camp_file)

    def validate_sia(self):
        event_coord = self.campaign['Events'][0]['Event_Coordinator_Config']
        Target_Age_Min = event_coord['Target_Age_Min']
        Target_Age_Max = event_coord['Target_Age_Max']
        coverage = event_coord['Demographic_Coverage']
        start_day = self.campaign['Events'][0]['Start_Day']

        self.assertEqual(self.Target_Age_Min, Target_Age_Min)
        self.assertEqual(self.Target_Age_Max, Target_Age_Max)
        self.assertEqual(self.timestep+1, start_day)

    def test_sia_default(self):
        import emodpy_measles.interventions.simple_sia as sia
        sia.schema_path = "schema.json"

        try:
            camp_filename = sia.new_intervention_as_file( 10 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking simple_vacsiane.new_intervention_as_file(10) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking simple_vacsiane.new_intervention_as_file(10) -- " + str( ex ) )

        self.timestep=1
        self.Target_Age_Min=0.75
        self.Target_Age_Max=5.0

        event = sia.SimpleSIA()
        camp.add( event, first=True )

        camp_file = "campaign_simple_sia.json"
        camp.save( camp_file )

        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)
        
        self.validate_sia()

        if not self.is_debugging:
            os.remove(camp_file)

    def test_sia_custom(self):
        import emodpy_measles.interventions.simple_sia as sia
        sia.schema_path = "schema.json"

        try:
            camp_filename = sia.new_intervention_as_file( 10 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking simple_vacsiane.new_intervention_as_file(10) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking simple_vacsiane.new_intervention_as_file(10) -- " + str( ex ) )

        self.timestep=1
        self.Target_Age_Min=0.75
        self.Target_Age_Max=5.0

        event = sia.SimpleSIA(timestep=self.timestep, Target_Age_Min=self.Target_Age_Min, Target_Age_Max=self.Target_Age_Max)
        camp.add( event, first=True )

        camp_file = "campaign_simple_sia.json"
        camp.save( camp_file )
        
        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)
        
        self.validate_sia()

        if not self.is_debugging:
            os.remove(camp_file)

==> emodpy_measles-0.0.30-py3-none-any.whl: tests/test_camp_interventions.py <==
#!/usr/bin/env python


from emodpy_measles.interventions import *
import unittest
import emod_api.campaign as camp
import json
import os

#event = ConstructHistoricalCampaigns()

class TestCampInterventions(unittest.TestCase):

    is_debugging = True

    def validate_measles_vaccine(self):
        target_event = self.campaign['Events'][0]
        coverage = target_event['Event_Coordinator_Config']['Demographic_Coverage']
        start_day = target_event['Start_Day']
        intervention_name = target_event['Event_Coordinator_Config']['Intervention_Config']['Intervention_Name']

        self.assertEqual(coverage, self.coverage)
        self.assertEqual(start_day, self.timestep + 1)
        self.assertEqual(intervention_name, "DelayedIntervention")

    def test_simplemcv1_default(self):
        import emod_api.campaign as camp
        import emodpy_measles.interventions.measles_vaccine as mv
        camp.schema_path = "schema.json"

        # testing that intervention as file creates file
        try:
            camp_filename = mv.new_intervention_as_file( camp, 10 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(10) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(10) -- " + str( ex ) )

        self.coverage = 1
        self.timestep = 1

        event = mv.SimpleMCV1(camp, timestep=1)
        camp.add(event, first=True)
        camp.add(mv.SimpleMCV1(camp, timestep=10))

        camp_file = "campaign_simple_mcv1.json"
        camp.save( camp_file )

        self.assertTrue(os.path.exists(camp_file))
        
        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)
        
        # Check that events are being added properly
        self.assertEqual(len(self.campaign['Events']), 2)
        self.validate_measles_vaccine()

        if not self.is_debugging:
            os.remove(camp_file)

    def test_simplemcv1_custom(self):
        import emodpy_measles.interventions.measles_vaccine as mv
        import emod_api.campaign as camp
        camp.schema_path = "schema.json"

        # testing that intervention as file creates file
        try:
            camp_filename = mv.new_intervention_as_file( camp, 20 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(20) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking simple_vaccine.new_intervention_as_file(20) -- " + str( ex ) )

        self.coverage = 1.0
        self.timestep = 5


        event = mv.SimpleMCV1(camp, coverage=self.coverage, timestep=self.timestep)
        camp.add(event, first=True)

        camp_file = "campaign_simple_mcv1.json"
        camp.save( camp_file )

        self.assertTrue(os.path.exists(camp_file))
        
        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)

        self.validate_measles_vaccine()

        if not self.is_debugging:
            os.remove(camp_file)

    def validate_complex_import(self):
        intervention_config = self.campaign['Events'][0]['Event_Coordinator_Config']['Intervention_Config']
        dips = intervention_config['Daily_Import_Pressures']
        durations = intervention_config['Durations']
        start_day = self.campaign['Events'][0]['Start_Day']

        self.assertEqual(dips, self.dips)
        self.assertEqual(start_day, self.timestep + 1)
        self.assertEqual(durations, self.durations)

    def test_complex_import_default(self):
        import emod_api.campaign as camp
        import emodpy_measles.interventions.complex_import as ci
        camp.schema_path = "schema.json"

        try:
            camp_filename = ci.new_intervention_as_file( camp, timestep=15 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking complex_import.new_intervention_as_file(15) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking complex_import.new_intervention_as_file(15) -- " + str( ex ) )

        self.durations  = [100000]
        self.dips =[1/(774*10)]
        self.timestep=1
        event = ci.ComplexImportationEvent( camp )
        camp.add(event, first=True)


        camp_file = "campaign_complex_import.json"
        camp.save( camp_file )
        self.assertTrue(os.path.exists(camp_file))
        
        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)

        self.validate_complex_import()

        if not self.is_debugging:
            os.remove(camp_file)

    def test_complex_import_custom(self):
        import emodpy_measles.interventions.complex_import as ci
        import emod_api.campaign as camp
        camp.schema_path = "schema.json"

        try:
            camp_filename = ci.new_intervention_as_file( camp, timestep=5 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking complex_import.new_intervention_as_file(5) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking complex_import.new_intervention_as_file(5) -- " + str( ex ) )

        self.durations  = [10, 10, 11, 15]
        self.dips =[10, 10, 11, 7]
        self.timestep=10
        event = ci.ComplexImportationEvent(camp, durs=self.durations, dips=self.dips, timestep=10)
        camp.add(event, first=True)


        camp_file = "campaign_complex_import.json"
        camp.save( camp_file )
        self.assertTrue(os.path.exists(camp_file))
        
        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)

        self.validate_complex_import()

        if not self.is_debugging:
            os.remove(camp_file)

    def validate_sia(self):
        event_coord = self.campaign['Events'][0]['Event_Coordinator_Config']
        Target_Age_Min = event_coord['Target_Age_Min']
        Target_Age_Max = event_coord['Target_Age_Max']
        coverage = event_coord['Demographic_Coverage']
        start_day = self.campaign['Events'][0]['Start_Day']

        self.assertEqual(self.Target_Age_Min, Target_Age_Min)
        self.assertEqual(self.Target_Age_Max, Target_Age_Max)
        self.assertEqual(self.timestep+1, start_day)

    def test_sia_default(self):
        import emod_api.campaign as camp
        import emodpy_measles.interventions.simple_sia as sia
        camp.schema_path = "schema.json"

        try:
            camp_filename = sia.new_intervention_as_file( camp, 10 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking sia.new_intervention_as_file(10) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking sia.new_intervention_as_file(10) -- " + str( ex ) )

        self.timestep=1
        self.Target_Age_Min=0.75
        self.Target_Age_Max=5.0

        event = sia.SimpleSIA( camp )
        camp.add( event, first=True )

        camp_file = "campaign_simple_sia.json"
        camp.save( camp_file )

        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)
        
        self.validate_sia()

        if not self.is_debugging:
            os.remove(camp_file)

    def test_sia_custom(self):
        import emod_api.campaign as camp
        import emodpy_measles.interventions.simple_sia as sia
        camp.schema_path = "schema.json"

        try:
            camp_filename = sia.new_intervention_as_file( camp, 10 )
            print( f"Check for valid campaign file at: {camp_filename}." )
        except ValueError as ex:
            print( "Caught exception invoking sia.new_intervention_as_file(10) -- " + str( ex.strerror ) )
        except Exception as ex:
            print( "Caught exception invoking sia.new_intervention_as_file(10) -- " + str( ex ) )

        self.timestep=1
        self.Target_Age_Min=0.75
        self.Target_Age_Max=5.0

        event = sia.SimpleSIA(camp, timestep=self.timestep, Target_Age_Min=self.Target_Age_Min, Target_Age_Max=self.Target_Age_Max)
        camp.add( event, first=True )

        camp_file = "campaign_simple_sia.json"
        camp.save( camp_file )
        
        with open(camp_file, 'r') as file:
            self.campaign = json.load(file)
        
        self.validate_sia()

        if not self.is_debugging:
            os.remove(camp_file)
